@@ -8,16 +8,11 @@ uploadify_css = Resource(
     library, 'uploadify.css',
 )
 
-swfobject_js = Resource(
-    library, 'swfobject.js',
-)
-
 uploadify_js = Resource(
     library, 'jquery.uploadify.js',
     minified='jquery.uploadify.min.js',
     depends=[
         jquery,
-        swfobject_js,
         uploadify_css,
     ],
 )
